require 'xds_b'
require 'xds_b.xop'

xds_b.ret = {} 
xds_b.ret.documentRequest = {}

require 'xds_b.ret.soap'

local addElement = node.addElement
local setInner = node.setInner

function xds_b.ret.new()
   local retDocumentSetXML = [[
        <RetrieveDocumentSetRequest xmlns="urn:ihe:iti:xds-b:2007"
            xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
        </RetrieveDocumentSetRequest>
   ]]
   
   return xml.parse{data=retDocumentSetXML}
end

local DocumentRequestAddHelp = {
   title="xds_b.ret.documentRequest.add",
   usage="xds_b.ret.documentRequest.add{target=<root tag>, repositoryId=<value>, documentId=<value>}",
   description="This function will add a document request construct to the xml document.",
   returns={
      "The node tree presenting the resulting xml construct"
   },
   parameters={
      target="The root xml where the name XML will be inserted",
      repositoryId="The id of repository where the document is stored",
      documentId="The id of the requested document"
   },
   examples={[[local DR = xds_b.ret.documentRequest.add{target=Root, repositoryId='1.19.6.24.109.42.1.5', 
      documentId='2009.9.1.1573'}]]}
}
   
function xds_b.ret.documentRequest.add(I)
   ihe.help.check(I, DocumentRequestAddHelp)
      
   local DR = addElement(I.target, 'DocumentRequest')
   local R = addElement(DR, 'RepositoryUniqueId')
   setInner(R, I.repositoryId)
   local D = addElement(DR, 'DocumentUniqueId')
   setInner(D, I.documentId)
   
   return DR
end
