require 'xds_b.ret'

xds_b.ret.simpleapi = {}

local setInner = node.setInner

local function WrapInSoap(RET)
   local S = xds_b.ret.soap.new{protocol='http', host='ihexds.nist.gov', port='12080', 
      path='/tf6/services/xdsrepositoryb'}
   setInner(S['soapenv:Envelope']['soapenv:Body'], tostring(RET['RetrieveDocumentSetRequest']))
   
   return S
end

function xds_b.ret.simpleapi.parseResponse(I)
   local Response = I.response
   
   local Status, ResponseXML = xds_b.xop.soap.extract{response=Response} 
   if Status then
      local XML = xml.parse{data=ResponseXML}
   
      local Root = XML['soapenv:Envelope']['soapenv:Body']['xdsb:RetrieveDocumentSetResponse']['rs:RegistryResponse']
      local Status = Root.status:nodeValue()
      
      if Status:find('Success') then
         return 'Success', xds_b.xop.attachments.extract{response=Response}
      else
         local Reason = Root['rs:RegistryErrorList']['rs:RegistryError'].codeContext:nodeValue()
         return 'Failure: '..Reason
      end
   else
      return 'Failure: '..ResponseXML
   end
end

local RETMakeHelp = {
   title="xds_b.ret.simpleapi.make",
   usage="xds_b.ret.simpleapi.make{repositoryId=<value>, documentId=<value>}",
   description=[[This function will build a Retrieve Document Set request using 
   the inputted repository and document UUIDs.]],
   returns={"The HTTP headers and body of the request"},
   parameters={      
      repositoryId="The UUID of the repository storing the document",
      documentId="The UUID of the document set to be retrieved"
   },
   examples={[[local Headers, Body = xds_b.ret.simpleapi.make{
      repositoryId='1.3.6.1.4.1.21367.2011.2.3.7', 
      documentId='1.42.20130705031122.190'
   }]]}
}

function xds_b.ret.simpleapi.make(I) 
   local RET = xds_b.ret.new()
   local DR = xds_b.ret.documentRequest.add{target=RET.RetrieveDocumentSetRequest, 
      repositoryId='1.3.6.1.4.1.21367.2011.2.3.7', documentId='1.42.20130705031122.190'} 
   
   local S = WrapInSoap(RET)

   local HTTPHeaders, ContentUUID, MimeUUID = 
   xds_b.getHTTPHeaders{action='RetrieveDocumentSet'}     
   local PackagedBody = xds_b.xop.attachments.add{content=ContentUUID, mime=MimeUUID, 
      soap=S, attachments={}}
 
   return HTTPHeaders, PackagedBody
end

ihe.help.set{func=xds_b.ret.simpleapi.make, info=RETMakeHelp}